Name:           stdair
Version:        1.00.12
Release:        3%{?dist}

Summary:        C++ Standard Airline IT Object Library

License:        LGPLv2+
URL:            https://github.com/airsim/%{name}
Source0:        %{url}/archive/%{name}-%{version}.tar.gz

BuildRequires:  gcc-c++
BuildRequires:  cmake
BuildRequires:  boost-devel
BuildRequires:  soci-mysql-devel
BuildRequires:  soci-sqlite3-devel
BuildRequires:  readline-devel


%description
%{name} aims at providing a clean API, and the corresponding C++
implementation, for the basis of Airline IT and travel distribution
Business Object Model (BOM), that is, to be used by several other open
source projects, such as AirRAC, RMOL, AirInv, AvlCal, AirSched, SimFQT,
SimLFS, SimCRS, TravelCCM, SEvMgr, TraDemGen, DSim, OpenTREP, etc.

Install the %{name} package if you need a library of basic C++ objects
for Airline IT (e.g., schedule management, inventory, revenue management,
revenue accounting), travel distribution, demand generation and customer choice
modeling, mainly for simulation purpose.

%package        devel
Summary:        Header files, libraries and development helper tools for %{name}
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       pkgconfig

%description    devel
This package contains the header files, shared libraries and
development helper tools for %{name}. If you would like to develop
programs using %{name}, you will need to install %{name}-devel.

%package        doc
Summary:        HTML documentation for the %{name} library
BuildRequires:  tex(latex)
BuildRequires:  doxygen
BuildRequires:  ghostscript
BuildRequires:  texlive-epstopdf

%description    doc
This package contains HTML pages, as well as a PDF reference manual,
for %{name}. All that documentation is generated thanks to Doxygen
(https://doxygen.org). The content is the same as what can be browsed
online (https://%{name}.org).


%prep
%autosetup -n %{name}-%{name}-%{version} 

%build
%cmake 
%cmake_build

%install
%cmake_install

# Fix some permissions
find %{buildroot}%{_libexecdir}/%{name} -type f -name '*.sh' -exec chmod +x {} \;

# Remove the Doxygen installer
rm -f %{buildroot}/%{_docdir}/%{name}/html/installdox

# Remove additional documentation files (those files are already available
# in the project top directory)
rm -f %{buildroot}%{_docdir}/%{name}/{NEWS,README.md,AUTHORS}

%check
ctest

%files
%doc ChangeLog AUTHORS NEWS README.md
%license COPYING
%{_bindir}/%{name}
%{_libdir}/lib%{name}.so.*
%{_libdir}/lib%{name}uicl.so.*
%{_mandir}/man1/%{name}.1.*
%dir %{_libexecdir}/%{name}
%{_libexecdir}/%{name}/*.sh
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/db
%dir %{_datadir}/%{name}/db/data
%dir %{_datadir}/%{name}/samples
%dir %{_datadir}/%{name}/samples/rds01
%dir %{_datadir}/%{name}/samples/HybridForecasting
%dir %{_datadir}/%{name}/samples/IBP_study
%dir %{_datadir}/%{name}/samples/NewQFF
%dir %{_datadir}/%{name}/samples/NewQFF/instance01
%dir %{_datadir}/%{name}/samples/NewQFF/instance02
%dir %{_datadir}/%{name}/samples/OldQFF
%dir %{_datadir}/%{name}/samples/OldQFF/instance01
%dir %{_datadir}/%{name}/samples/OldQFF/instance02
%dir %{_datadir}/%{name}/samples/QForecasting
%{_datadir}/%{name}/db/data/*.sql
%{_datadir}/%{name}/db/data/*.csv
%{_datadir}/%{name}/samples/*.csv
%{_datadir}/%{name}/samples/rds01/*.csv
%{_datadir}/%{name}/samples/HybridForecasting/*.csv
%{_datadir}/%{name}/samples/IBP_study/*.csv
%{_datadir}/%{name}/samples/NewQFF/instance01/*.csv
%{_datadir}/%{name}/samples/NewQFF/instance02/*.csv
%{_datadir}/%{name}/samples/OldQFF/instance01/*.csv
%{_datadir}/%{name}/samples/OldQFF/instance02/*.csv
%{_datadir}/%{name}/samples/QForecasting/*.csv

%files devel
%{_includedir}/%{name}
%{_bindir}/%{name}-config
%{_libdir}/lib%{name}.so
%{_libdir}/lib%{name}uicl.so
%{_libdir}/pkgconfig/%{name}.pc
%{_datadir}/aclocal/%{name}.m4
%{_datadir}/%{name}/CMake
%{_mandir}/man1/%{name}-config.1.*
%{_mandir}/man3/%{name}-library.3.*

%files doc
%doc %{_docdir}/%{name}/html
%license COPYING


%changelog
* Sat Jan 21 2023 Fedora Release Engineering <releng@fedoraproject.org> 1.00.12-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Sat Jul 23 2022 Fedora Release Engineering <releng@fedoraproject.org> 1.00.12-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Sun Jul 10 2022 Denis Arnaud <denis.arnaud_fedora@m4x.org> 1.00.12-1
- Upgraded to 1.00.12

* Wed May 04 2022 Thomas Rodgers <trodgers@redhat.com> 1.00.10-14
- Rebuilt for Boost 1.78

* Sat Jan 22 2022 Fedora Release Engineering <releng@fedoraproject.org> 1.00.10-13
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Fri Aug 06 2021 Jonathan Wakely <jwakely@redhat.com> 1.00.10-12
- Rebuilt for Boost 1.76

* Fri Jul 23 2021 Fedora Release Engineering <releng@fedoraproject.org> 1.00.10-11
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Wed Jan 27 2021 Fedora Release Engineering <releng@fedoraproject.org> 1.00.10-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Fri Jan 22 2021 Jonathan Wakely <jwakely@redhat.com> 1.00.10-9
- Rebuilt for Boost 1.75

* Sun Aug 09 2020 Denis Arnaud <denis.arnaud_fedora@m4x.org> 1.00.10-8
- More consistent buildroot

* Sun Aug 09 2020 Denis Arnaud <denis.arnaud_fedora@m4x.org> 1.00.10-7
- Removed the docdir work around (no longer needed)

* Tue Aug 04 2020 Denis Arnaud <denis.arnaud_fedora@m4x.org> 1.00.10-6
- CMake build out of source. Fixes BZ#1865515

* Sat Aug 01 2020 Fedora Release Engineering <releng@fedoraproject.org> 1.00.10-5
- Second attempt - Rebuilt for
  https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Wed Jul 29 2020 Fedora Release Engineering <releng@fedoraproject.org> 1.00.10-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Thu Jun 04 2020 Denis Arnaud <denis.arnaud_fedora@m4x.org> 1.00.10-3
- Rebuilt for SOCI 4.0.1.alpha1

* Wed Jun 03 2020 Denis Arnaud <denis.arnaud_fedora@m4x.org> 1.00.10-2
- Rebuilt for Boost 1.73

* Sun May 31 2020 Denis Arnaud <denis.arnaud_fedora@m4x.org> 1.00.10-1
- Upstream update

* Sun May 31 2020 Denis Arnaud <denis.arnaud_fedora@m4x.org> 1.00.9-1
- Upstream update. No more dependency on Python

* Thu May 28 2020 Jonathan Wakely <jwakely@redhat.com> 1.00.8-10
- Rebuilt for Boost 1.73

* Sun Feb 16 2020 Denis Arnaud <denis.arnaud_fedora@m4x.org> 1.00.8-9
- Made the -doc subpackage arch dependent (as some files depend on the
  arch)

* Sun Feb 16 2020 Denis Arnaud <denis.arnaud_fedora@m4x.org> 1.00.8-8
- Attempt to fix the doc noarch issue

* Fri Jan 31 2020 Fedora Release Engineering <releng@fedoraproject.org> 1.00.8-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Tue Nov 05 2019 Denis Arnaud <denis.arnaud_fedora@m4x.org> 1.00.8-6
- Rebuild for SOCI 4.0.0-rc1

* Mon Nov 04 2019 Denis Arnaud <denis.arnaud_fedora@m4x.org> 1.00.8-5
- Rebuild for SOCI 4.0.0-rc1

* Mon Aug 19 2019 Miro Hrončok <miro@hroncok.cz> 1.00.8-4
- Rebuilt for Python 3.8

* Sat Jul 27 2019 Fedora Release Engineering <releng@fedoraproject.org> 1.00.8-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Thu Jul 11 2019 Miro Hrončok <miro@hroncok.cz> 1.00.8-2
- Pin the Python version this was built with

* Thu Jul 11 2019 Denis Arnaud <denis.arnaud_fedora@m4x.org> 1.00.8-1
- CMake support files updated for Python 3.8

* Sun Feb 03 2019 Fedora Release Engineering <releng@fedoraproject.org> 1.00.7-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Thu Jan 24 2019 Jonathan Wakely <jwakely@redhat.com> 1.00.7-4
- Rebuilt for Boost 1.69

* Thu Jan 17 2019 Denis Arnaud <denis.arnaud_fedora@m4x.org> 1.00.7-3
- Fixed a typo in Python library directory

* Tue Jan 15 2019 Denis Arnaud <denis.arnaud_fedora@m4x.org> 1.00.7-1
- Upstream update

* Sat Jul 14 2018 Fedora Release Engineering <releng@fedoraproject.org> 1.00.6-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Mon Jul 09 2018 Igor Gnatenko <ignatenko@redhat.com> 1.00.6-5
- add BuildRequires: gcc-c++

* Thu May 10 2018 Jonathan Wakely <jwakely@redhat.com> 1.00.6-4
- Add BuildRequires: boost-python2-devel to fix build with
  boost-1.66.0-7.fc29

* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> 1.00.6-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Mon Jan 22 2018 Jonathan Wakely <jwakely@redhat.com> 1.00.6-2
- Rebuilt for Boost 1.66

* Sun Aug 06 2017 Denis Arnaud (Fedora Packager) <denis.arnaud_fedora@m4x.org> 1.00.6-1
- Fixed the FTBFS issue related to newer Boost Serialization (from 1.63).

* Thu Aug 03 2017 Fedora Release Engineering <releng@fedoraproject.org> 1.00.5-6
- Rebuilt for
  https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Mon Jul 31 2017 Filipe Rosset <rosset.filipe@gmail.com> 1.00.5-5
- Spec clean up

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> 1.00.5-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Sun Jul 23 2017 Björn Esser <besser82@fedoraproject.org> 1.00.5-3
- Rebuilt for Boost 1.64

* Mon May 15 2017 Fedora Release Engineering <releng@fedoraproject.org> 1.00.5-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_27_Mass_Rebuild

* Sat Feb 25 2017 Denis Arnaud <denis.arnaud_fedora@m4x.org> 1.00.5-1
- Upstream update

* Sat Feb 25 2017 Denis Arnaud <denis.arnaud_fedora@m4x.org> 1.00.2-18
- Attempt to fix the FTBFS issue related to new Boost 1.63 serialization

* Sat Feb 25 2017 Denis Arnaud <denis.arnaud_fedora@m4x.org> 1.00.2-17
- Attempt to fix the FTBFS issue related to new Boost 1.63 serialization

* Sat Feb 25 2017 Denis Arnaud <denis.arnaud_fedora@m4x.org> 1.00.2-16
- Attempt to fix the FTBFS issue related to new Boost 1.63 serialization

* Sat Feb 25 2017 Denis Arnaud <denis.arnaud_fedora@m4x.org> 1.00.2-15
- Attempt to fix the FTBFS issue related to new Boost 1.63 serialization

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> 1.00.2-14
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Tue May 17 2016 Jonathan Wakely <jwakely@redhat.com> 1.00.2-13
- Rebuilt for linker errors in boost (#1331983)

* Fri Feb 05 2016 Fedora Release Engineering <releng@fedoraproject.org> 1.00.2-12
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Sat Jan 16 2016 Jonathan Wakely <jwakely@redhat.com> 1.00.2-11
- Rebuilt for Boost 1.60

* Sat Aug 29 2015 Jonathan Wakely <jwakely@redhat.com> 1.00.2-10
- Fix patch for Boost.Log

* Sat Aug 29 2015 Jonathan Wakely <jwakely@redhat.com> 1.00.2-9
- Patched and rebuilt for Boost 1.59

* Wed Jul 29 2015 Dennis Gilmore <dennis@ausil.us> 1.00.2-8
- Rebuilt for https://fedoraproject.org/wiki/Changes/F23Boost159

* Wed Jul 22 2015 David Tardon <dtardon@redhat.com> 1.00.2-7
- rebuild for Boost 1.58

* Fri Jun 19 2015 Dennis Gilmore <dennis@ausil.us> 1.00.2-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sun Jun 07 2015 Denis Arnaud <denis.arnaud_fedora@m4x.org> 1.00.2-5
- Removed the unused dependency on zeromq-devel

* Sun May 31 2015 Denis Arnaud <denis.arnaud_fedora@m4x.org> 1.00.2-3
- Removed the dependency on ZeroMQ (only AirInv is dependent on it, not
  StdAir)

* Sun May 31 2015 Denis Arnaud <denis.arnaud_fedora@m4x.org> 1.00.2-1
- Removed the dependency on ZeroMQ (only AirInv is dependent on it, not
  StdAir)

* Sat May 02 2015 Kalev Lember <kalevlember@gmail.com> 1.00.1-16
- Rebuilt for GCC 5 C++11 ABI change

* Wed Jan 28 2015 Petr Machata <pmachata@redhat.com> 1.00.1-15
- Cmake should look for zmq.h, not zmq.hpp (stdair-1.00.1-cmake.patch)

* Tue Jan 27 2015 Petr Machata <pmachata@redhat.com> 1.00.1-14
- Rebuild for boost 1.57.0

* Mon Aug 18 2014 Peter Robinson <pbrobinson@fedoraproject.org> 1.00.1-13
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sat Jun 14 2014 Denis Arnaud <denis.arnaud_fedora@m4x.org> 1.00.1-12
- Rebuild for ARM architecture. It seems to work by now:

* Sun Jun 08 2014 Dennis Gilmore <dennis@ausil.us> 1.00.1-11
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Thu May 22 2014 Petr Machata <pmachata@redhat.com> 1.00.1-10
- Rebuild for boost 1.55.0

* Sun Aug 04 2013 Dennis Gilmore <dennis@ausil.us> 1.00.1-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Mon Jul 29 2013 Denis Arnaud <denis.arnaud_fedora@m4x.org> 1.00.1-8
- Fixed the docdir issue, following the F20 System Wide Change

* Sat Jul 27 2013 Petr Machata <pmachata@redhat.com> 1.00.1-7
- Rebuild for boost 1.54.0

* Sun Jun 02 2013 Denis Arnaud <denis.arnaud_fedora@m4x.org> 1.00.1-6
- Bump the version to be consistent with F19

* Wed May 22 2013 Denis Arnaud <denis.arnaud_fedora@m4x.org> 1.00.1-5
- Rebuild for Soci-3.2.1

* Sat Feb 09 2013 Denis Arnaud <denis.arnaud_fedora@m4x.org> 1.00.1-4
- Rebuild for Boost-1.53.0

* Wed Jan 02 2013 Denis Arnaud <denis.arnaud_fedora@m4x.org> 1.00.1-3
- Bump the version to be consistent with F18

* Sun Dec 23 2012 Denis Arnaud <denis.arnaud_fedora@m4x.org> 1.00.1-1
- Upstream update

* Sat Dec 22 2012 Denis Arnaud <denis.arnaud_fedora@m4x.org> 1.00.0-1
- Upstream update

* Sun Aug 12 2012 Kevin Fenzi <kevin@scrye.com> 0.45.1-4
- Rebuild for new boost

* Sat Jul 21 2012 Dennis Gilmore <dennis@ausil.us> 0.45.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Tue Feb 28 2012 Dennis Gilmore <dennis@ausil.us> 0.45.1-2
- Rebuilt for c++ ABI breakage

* Sun Jan 15 2012 Denis Arnaud <denis.arnaud_fedora@m4x.org> 0.45.1-1
- Upstream update

* Sat Jan 14 2012 Dennis Gilmore <dennis@ausil.us> 0.45.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Mon Dec 05 2011 Denis Arnaud <denis.arnaud_fedora@m4x.org> 0.45.0-3
- [Build] Fixed the wrong end-of-line CMake build issue.

* Sun Dec 04 2011 Denis Arnaud <denis.arnaud_fedora@m4x.org> 0.45.0-2
- [Build] Now build externally, out of the source directory.

* Sun Dec 04 2011 Denis Arnaud <denis.arnaud_fedora@m4x.org> 0.45.0-1
- Upstream update

* Sun Nov 20 2011 Denis Arnaud <denis.arnaud_fedora@m4x.org> 0.44.1-2
- Rebuild for the new Boost-1.48.0

* Sat Nov 05 2011 Denis Arnaud <denis.arnaud_fedora@m4x.org> 0.44.1-1
- Upstream update

* Wed Nov 02 2011 Denis Arnaud <denis.arnaud_fedora@m4x.org> 0.44.0-1
- Upstream update

* Sat Oct 15 2011 Denis Arnaud <denis.arnaud_fedora@m4x.org> 0.43.0-2
- Improved a little the package descriptions

* Sat Oct 15 2011 Denis Arnaud <denis.arnaud_fedora@m4x.org> 0.43.0-1
- Upstream update

* Mon Aug 15 2011 Denis Arnaud <denis.arnaud_fedora@m4x.org> 0.38.0-1
- Upstream update

* Fri Aug 12 2011 Adam Jackson <ajax@redhat.com> 0.36.2-3
- Rebuild for new boost

* Tue Aug 02 2011 Denis Arnaud <denis.arnaud_fedora@m4x.org> 0.36.2-1
- New package: StdAir-0.36.2-1 on Fedora Rawhide.
